#!/usr/bin/php
<?php

/**
 * WebService SsODNet.datacloud - acces aux donnees des Sso
 *   NameSpace : https://ssp.imcce.fr/webservices/ssodnet
 *   WSDL      : https://ssp.imcce.fr/webservices/ssodnet/ssodnet.wsdl
 *   Method    : datacloud
 *   Parameters:  name     -> Name of the system, e.g. a:kalliope
 *                resource -> List of requested resources
 *                mime     -> Output format ('votable')
 *                maxrec   -> nombre maximum de corps resolus (optionnel, default 10)
 *                from     -> Client's ID
 *   Response  : Data of the requested Sso
 * 
 * @author J. Berthier (IMCCE/OBSPM) <berthier@imcce.fr> & F. Vachier (IMCCE) <fv@imcce.fr>
 * @copyright (C) 2005-2019, IMCCE/OBSPM
 * @since PHP7
 * @version 2.0
 */

// Definition du decalage horaire
date_default_timezone_set("UTC");

// Mise en cache ou non du WSDL du service
ini_set('soap.wsdl_cache_enabled', 1);
ini_set('default_socket_timeout', 3600);

// Namespace et WSDL du service
$uri = 'http://ssp.localhost/webservices/ssodnet';
$wsdl = $uri.'/ssodnet.wsdl';

// Default method
$method = 'datacloud';

// Definition of parameters
$name     = 'a:=:io';
$resource = 'diamalbedos';
$mime     = 'json';
$maxrec   = 10;

// Input array of the service
$param = array(
   'name'     => $name,
   'resource' => $resource,
   'mime'     => $mime,
   'maxrec'   => $maxrec
);

// Client's ID
$from = 'DemoClient';
// Client's host IP pour l'entete SOAP
$hostip = '';


// Execution de la requete
try 
{
  // Instantiation du client
  $client = new SoapClient($wsdl, array('exceptions'=>1, 'trace'=>1));
  // Parametres de l'entete SOAP
  $header = array('from'=>$from, 'hostip'=>'', 'export'=>false);
  // Construction de l'entete SOAP
  $client->__setSoapHeaders(array(new SOAPHeader($uri, 'clientID', $header)));
  // Appel de la methode
  $response = $client->__soapCall($method, array($param));

//echo "REQUEST:\n" . $client->__getLastRequest() . "\n";
//echo "RESPONSE HEADER:\n" . $client->__getLastResponseHeaders() . "\n";
//echo "RESPONSE:\n" . $client->__getLastResponse() . "\n";

  // Affichage des resultats
  header("HTTP/1.0 ".$response->status);
  // Affichage des donnees selon le mime-type
  if ($param['mime'] == 'votable') {
    header("Content-Type: text/xml;content=x-votable");
    echo $response->result;
  } else if ($param['mime'] == 'json') {
    header("Content-Type: application/json");
    echo $response->result;
  } else {
    header("Content-Type: text/plain");
    echo "# Flag: ".$response->flag.PHP_EOL;
    echo "# Ticket: ".$response->ticket.PHP_EOL;
    echo "# Result: ".PHP_EOL;
    $res = explode(';', $response->result);
    foreach ($res as $key => $value) {
      echo $value.PHP_EOL;
    }

  }
}
catch (SoapFault $fault) 
{
  trigger_error("SOAP Fault: {$fault->getTraceAsString()} (faultcode: {$fault->faultcode}, faultstring: {$fault->faultstring})", E_USER_ERROR);
}

?>
