#!/usr/bin/php
<?php

/**
 * WebService SsODNet::resolver - resolver de nom des Sso
 *   NameSpace : https://ssp.imcce.fr/webservices/ssodnet/
 *   WSL       : https://ssp.imcce.fr/webservices/ssodnet/ssodnet.wsdl
 *   Method    : resolver 
 * 
 * @author J. Berthier (IMCCE/OBSPM) <berthier@imcce.fr> & J.Normand (IMCCE/OBSPM) <jonathan.normand@obspm.fr>
 * @copyright (C) 2005-2016, IMCCE
 * @since PHP5
 * @version 2.0
 */

// Definition du decalage horaire
date_default_timezone_set("UTC");

// Mise en cache ou non du WSDL du service
ini_set('soap.wsdl_cache_enabled', 1);
ini_set('default_socket_timeout', 3600);

// Namespace et URI du service
$uri  = 'https://ssp.imcce.fr/webservices/ssodnet'; 
$wsdl = $uri.'/ssodnet.wsdl';

// Default method
$method = 'resolver';

// Input parameter
// Parametres du service
$param = array(
  'name'   => 'io',
  'mime'   => 'json',
  'epoch'  => 'now',
  'maxrec' => 0,
  'ephem'  => 1 
);

// Client's ID
$from = 'DemoClient';
// Client's host IP pour l'entete SOAP
$hostip = '';

// Execution de la requete
try 
{
  // Instantiation du client
  $client = new SoapClient($wsdl, array('exceptions'=>1));
  // Parametres de l'entete SOAP
  $header = array('from'=>$from, 'hostip'=>$hostip);
  // Construction de l'entete SOAP
  $client->__setSoapHeaders(array(new SOAPHeader($uri, 'clientID', $header)));
  // Appel de la methode
  $response = $client->__soapCall($method, array($param));

//  echo "REQUEST:\n" . $client->__getLastRequest() . "\n";
//  echo "RESPONSE:\n" . $client->__getLastResponse() . "\n";
  
  // Affichage du resultat
  if ($param['mime'] == 'text')
  {
    $res = explode(';', $response->result);
    $nbr = count($res);
    $newkey = array_keys($res);
    header("HTTP/1.0 ".$response->status);
    header("Content-Type: text/plain");
    for ($i=0; $i<$nbr; $i++) { echo trim($res[$newkey[$i]]),"\n"; };
  }
  else if ($param['mime'] == 'json')
  {
    header("HTTP/1.0 ".$response->status);
    header("Content-Type: application/json");
    echo $response->result;
  }
  else
  {
    header("HTTP/1.0 ".$response->status);
    header("Content-Type: text/xml;content=x-votable");
    echo $response->result."\n";
  }
} 
catch (SoapFault $fault) 
{
  header("HTTP/1.0 500");
  trigger_error("SOAP Fault: {$fault->getTraceAsString()} (faultcode: {$fault->faultcode}, faultstring: {$fault->faultstring})", E_USER_ERROR);
}

?>
